@@ -278,11 +278,9 @@ xml_start_element_handler_metadata (GMarkupParseContext  *context,
 		data->current = ODT_TAG_TYPE_COMMENTS;
 	} else if (g_ascii_strcasecmp (element_name, "meta:document-statistic") == 0) {
 		TrackerSparqlBuilder *metadata;
-		const gchar *uri;
 		const gchar **a, **v;
 
 		metadata = data->metadata;
-		uri = data->uri;
 
 		for (a = attribute_names, v = attribute_values; *a; ++a, ++v) {
 			if (g_ascii_strcasecmp (*a, "meta:word-count") == 0) {
@@ -322,12 +320,15 @@ xml_text_handler_metadata (GMarkupParseContext  *context,
 {
 	ODTMetadataParseInfo *data;
 	TrackerSparqlBuilder *metadata;
-	const gchar *uri;
 	gchar *date;
 
 	data = user_data;
 	metadata = data->metadata;
-	uri = data->uri;
+
+	if (text_len == 0) {
+		/* ignore empty values */
+		return;
+	}
 
 	switch (data->current) {
 	case ODT_TAG_TYPE_TITLE:
@@ -383,9 +384,11 @@ xml_text_handler_metadata (GMarkupParseContext  *context,
 
 	case ODT_TAG_TYPE_CREATED:
 		date = tracker_date_guess (text);
-		tracker_sparql_builder_predicate (metadata, "nie:contentCreated");
-		tracker_sparql_builder_object_unvalidated (metadata, date);
-		g_free (date);
+		if (date) {
+			tracker_sparql_builder_predicate (metadata, "nie:contentCreated");
+			tracker_sparql_builder_object_unvalidated (metadata, date);
+			g_free (date);
+		}
 		break;
 
 	case ODT_TAG_TYPE_GENERATOR:
