@@ -20,6 +20,17 @@
 
 #include "config.h"
 
+#ifndef _GNU_SOURCE
+#define _GNU_SOURCE
+#endif
+
+#include <errno.h>
+#include <fcntl.h>
+#include <string.h>
+#include <sys/types.h>
+#include <sys/stat.h>
+#include <unistd.h>
+
 #include <glib/gstdio.h>
 
 #include <tiffio.h>
@@ -269,6 +280,7 @@ extract_tiff (const gchar          *uri,
 	GPtrArray *keywords;
 	guint i;
 	GString *where = NULL;
+	int fd;
 
 #ifdef HAVE_LIBIPTCDATA
 	gchar *iptc_offset;
@@ -282,9 +294,23 @@ extract_tiff (const gchar          *uri,
 
 	filename = g_filename_from_uri (uri, NULL, NULL);
 
-	if ((image = TIFFOpen (filename, "r")) == NULL){
+	fd = g_open (filename, O_RDONLY | O_NOATIME, 0);
+	if (fd == -1 && errno == EPERM) {
+		fd = g_open (filename, O_RDONLY, 0);
+	}
+
+	if (fd == -1) {
+		g_warning ("Could not open tiff file '%s': %s\n",
+		           filename,
+		           g_strerror (errno));
+		g_free (filename);
+		return;
+	}	
+
+	if ((image = TIFFFdOpen (fd, filename, "r")) == NULL){
 		g_warning ("Could not open image:'%s'\n", filename);
 		g_free (filename);
+		close (fd);
 		return;
 	}
 
@@ -479,6 +505,10 @@ extract_tiff (const gchar          *uri,
 		tracker_sparql_builder_object_unvalidated (metadata, xd->license);
 	}
 
+        if (xd->regions) {
+	        tracker_xmp_apply_regions (preupdate, metadata, NULL, xd);
+        }
+
 	if (md.address || md.state || md.country || md.city ||
 	    md.gps_altitude || md.gps_latitude || md.gps_longitude) {
 
@@ -770,6 +800,7 @@ extract_tiff (const gchar          *uri,
 	tracker_exif_free (ed);
 	tracker_xmp_free (xd);
 	tracker_iptc_free (id);
+	close (fd);
 }
 
 TrackerExtractData *
