@@ -25,6 +25,7 @@
 #include <gio/gunixoutputstream.h>
 
 #include <libtracker-common/tracker-file-utils.h>
+#include <libtracker-common/tracker-common.h>
 
 #include "tracker-writeback-file.h"
 
@@ -214,8 +215,8 @@ tracker_writeback_file_update_metadata (TrackerWriteback         *writeback,
 		g_object_unref (file_info);
 
 		g_set_error_literal (error,
-		                     G_IO_ERROR,
-		                     G_IO_ERROR_FAILED,
+		                     TRACKER_DBUS_ERROR,
+		                     TRACKER_DBUS_ERROR_UNSUPPORTED,
 		                     "Module does not support writeback for this file");
 
 		return FALSE;
